@@ -6,5 +6,5 @@
 ( cd usr/bin ; ln -sf /usr/lib/python2.4/site-packages/pynche/pynche pynche )
 ( cd usr/bin ; rm -rf modulator )
 ( cd usr/bin ; ln -sf /usr/lib/python2.4/site-packages/modulator/modulator.py modulator )
-( cd usr/doc/python-2.4 ; rm -rf Tools )
-( cd usr/doc/python-2.4 ; ln -sf /usr/lib/python2.4/site-packages Tools )
+( cd usr/doc/python-2.4.1 ; rm -rf Tools )
+( cd usr/doc/python-2.4.1 ; ln -sf /usr/lib/python2.4/site-packages Tools )
